starcluster.managers

Package starcluster :: Module managers |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.managers

     1  #!/usr/bin/env python
     2
     3
     4 -class Manager(object):
     5      """
     6      Base class for all Manager classes in StarCluster
     7      """
     8 -    def __init__(self, cfg, ec2=None):
     9          self.cfg = cfg
    10          self.ec2 = ec2 or cfg.get_easy_ec2()
    11